#include "Types.r"
#include "OCETemplates.h"
#include "OCE.r"


/////////////////////////////////////////////////////////////////////////
//
// BOOKKEEPING - this is an aspect template with this base resource id
//
/////////////////////////////////////////////////////////////////////////

#define kAlbum2ndInfoPageAspect		kDETThirdID

resource 'deta' (kAlbum2ndInfoPageAspect, purgeable) {
	0,					// Drop priority
	dropCheckAlways,	// Drop check flag
	notMainAspect		// Not the main aspect
};

resource 'rstr' (kAlbum2ndInfoPageAspect+kDETTemplateName, purgeable) {
	"Album Second Info Page Aspect"
};



/////////////////////////////////////////////////////////////////////////
//
// BINDING - associate this aspect with records of this type
//
/////////////////////////////////////////////////////////////////////////

resource 'rstr' (kAlbum2ndInfoPageAspect+kDETRecordType, purgeable) {
	"Album"
};


// Icons
include "AlbumIcons" 'ICN#'(0) as 'ICN#'(kAlbum2ndInfoPageAspect+kDETAspectMainBitmap, purgeable);
include "AlbumIcons" 'icl4'(0) as 'icl4'(kAlbum2ndInfoPageAspect+kDETAspectMainBitmap, purgeable);
include "AlbumIcons" 'icl8'(0) as 'icl8'(kAlbum2ndInfoPageAspect+kDETAspectMainBitmap, purgeable);


/////////////////////////////////////////////////////////////////////////
//
// ASPECT PROPERTIES - shared between aspect and info page(s)
//
/////////////////////////////////////////////////////////////////////////

#define prNumTracks					kDETFirstDevProperty
#define prPlayingTimeHours			kDETFirstDevProperty + 1
#define prPlayingTimeMinutes		kDETFirstDevProperty + 2
#define prPlayingTimeSeconds		kDETFirstDevProperty + 3


//----------------------------------------------------------------------
//
// Lookup resource - what attributes to lookup,
//					 how to assign them to properties
//
//----------------------------------------------------------------------

resource 'dett' (kAlbum2ndInfoPageAspect+kDETAspectLookup, purgeable) {
	{
	{"Album Track Info"}, typeBinary,
		useForInput, useForOutput, notInSublist, isNotAlias, isNotRecordRef,
		{
			'word', prNumTracks, 0;
			'long', prPlayingTimeHours, 0;
			'long', prPlayingTimeMinutes, 0;
			'long', prPlayingTimeSeconds, 0;
		};
	}
};


//----------------------------------------------------------------------
//
// Balloon help for the properties
//
//----------------------------------------------------------------------

resource 'rst#' (kAlbum2ndInfoPageAspect+kDETAspectBalloons,purgeable) {
	{
	"The number of tracks on the album.",			"The number of tracks on the album. Uneditable because the record is locked or access controled.",
	"The number of hours of music on the album.",	"The number of hours of music on the album. Uneditable because the record is locked or access controled.",
	"The number of minutes of music on the album.",	"The number of minutes of music on the album. Uneditable because the record is locked or access controled.",
	"The number of seconds of music on the album.",	"The number of seconds of music on the album. Uneditable because the record is locked or access controled.",
	}
};



// --------------------------------------------------------------------
// --------------------------------------------------------------------
//
// Album Information Page
//
// --------------------------------------------------------------------
// --------------------------------------------------------------------


/////////////////////////////////////////////////////////////////////////
//
// BOOKKEEPING - this is an information page template with this base resource id
//				 and this view
//
/////////////////////////////////////////////////////////////////////////

#define kAlbum2ndInfoPage			kDETFourthID

resource 'deti' (kAlbum2ndInfoPage, purgeable) {
	2000,
	{0, 0, 0, 0},
	selectFirstText, 
	{
		kDETNoProperty, kDETNoProperty, kAlbum2ndInfoPage;
		kDETNoProperty, kDETNoProperty, kAlbum2ndInfoPage + 1;
		kDETNoProperty, kDETNoProperty, kAlbum2ndInfoPage + 2;
	},
	{
	}
};

resource 'rstr' (kAlbum2ndInfoPage+kDETTemplateName, purgeable) {
	"Album 2nd Info Page"
};

resource 'rstr' (kAlbum2ndInfoPage+kDETInfoPageName, purgeable) {
	"Track Info"
};


/////////////////////////////////////////////////////////////////////////
//
// BINDING - associate this information page with records of this type
//			 and with this aspect
//
/////////////////////////////////////////////////////////////////////////

resource 'rstr' (kAlbum2ndInfoPage+kDETRecordType, purgeable) {
	"Album"
};

resource 'rstr' (kAlbum2ndInfoPage+kDETInfoPageMainViewAspect, purgeable) {
	"Album Second Info Page Aspect"
};


/////////////////////////////////////////////////////////////////////////
//
// VIEWS - what you see in this information page
//
/////////////////////////////////////////////////////////////////////////


#define kMyFirstColumnLeft				(55)
#define kMyFirstColumnRight				(kMyFirstColumnLeft + 120)
#define kEditTextWidth					(23)
#define kSpaceBeforeEditDesc			(25)
#define kNumEditColumns					(3)
#define kMyEditColumnWidth				(70)
#define k1stEditColumnLeft				(kMyFirstColumnRight + 2)
#define k2ndEditColumnLeft				(k1stEditColumnLeft + kMyEditColumnWidth)
#define k3rdEditColumnLeft				(k2ndEditColumnLeft + kMyEditColumnWidth)
#define k4thEditColumnLeft				(k3rdEditColumnLeft + kMyEditColumnWidth)

#define kNumTracksTop					(40)
#define kNumTracksBottom				(kNumTracksTop + kDETAppFontLineHeight + 4)
#define kPlayingTimeTop					(kNumTracksBottom + 4)
#define kPlayingTimeBottom				(kPlayingTimeTop + kDETAppFontLineHeight + 4)
#define k2ndColumnRightInset			(kDETRecordInfoWindWidth - 10)

resource 'detv' (kAlbum2ndInfoPage, purgeable) {
	{
	kDETSubpageIconRect, kDETNoFlags, kDETAspectMainBitmap,
	Bitmap { kDETLargeIcon };
	}
};

resource 'detv' (kAlbum2ndInfoPage + 1, purgeable) {
	{
	{kNumTracksTop, kMyFirstColumnLeft, kNumTracksBottom, kMyFirstColumnRight}, kDETNoFlags, kDETNoProperty,
	StaticTextFromView { kDETApplicationFont, kDETApplicationFontSize, kDETRight, kDETBold,
		"Number of tracks:" };

	{kNumTracksTop-2, k1stEditColumnLeft, kNumTracksBottom-2, k1stEditColumnLeft + kEditTextWidth}, kDETEnabled + kDETNumericOnly, prNumTracks,
	EditText { kDETApplicationFont, kDETApplicationFontSize, kDETLeft, kDETNormal };
	}
};

resource 'detv' (kAlbum2ndInfoPage + 2, purgeable) {
	{
	{kPlayingTimeTop, kMyFirstColumnLeft, kPlayingTimeBottom, kMyFirstColumnRight}, kDETNoFlags, kDETNoProperty,
	StaticTextFromView { kDETApplicationFont, kDETApplicationFontSize, kDETRight, kDETBold,
		"Total playing time:" };

	{kPlayingTimeTop-2, k1stEditColumnLeft, kPlayingTimeBottom-2, k1stEditColumnLeft + kEditTextWidth}, kDETEnabled + kDETNumericOnly, prPlayingTimeHours,
	EditText { kDETApplicationFont, kDETApplicationFontSize, kDETLeft, kDETNormal };

	{kPlayingTimeTop, k1stEditColumnLeft + kSpaceBeforeEditDesc, kPlayingTimeBottom, k2ndEditColumnLeft}, kDETNoFlags, kDETNoProperty,
	StaticTextFromView { kDETApplicationFont, kDETApplicationFontSize, kDETLeft, kDETNormal,
		"Hours" };

	{kPlayingTimeTop-2, k2ndEditColumnLeft, kPlayingTimeBottom-2, k2ndEditColumnLeft + kEditTextWidth}, kDETEnabled + kDETNumericOnly, prPlayingTimeMinutes,
	EditText { kDETApplicationFont, kDETApplicationFontSize, kDETLeft, kDETNormal };

	{kPlayingTimeTop, k2ndEditColumnLeft + kSpaceBeforeEditDesc, kPlayingTimeBottom, k3rdEditColumnLeft}, kDETNoFlags, kDETNoProperty,
	StaticTextFromView { kDETApplicationFont, kDETApplicationFontSize, kDETLeft, kDETNormal,
		"Minutes" };

	{kPlayingTimeTop-2, k3rdEditColumnLeft, kPlayingTimeBottom-2, k3rdEditColumnLeft + kEditTextWidth}, kDETEnabled + kDETNumericOnly, prPlayingTimeSeconds,
	EditText { kDETApplicationFont, kDETApplicationFontSize, kDETLeft, kDETNormal };

	{kPlayingTimeTop, k3rdEditColumnLeft + kSpaceBeforeEditDesc, kPlayingTimeBottom, k4thEditColumnLeft}, kDETNoFlags, kDETNoProperty,
	StaticTextFromView { kDETApplicationFont, kDETApplicationFontSize, kDETLeft, kDETNormal,
		"Seconds" };
	}
};

